summaryrefslogtreecommitdiffstats
path: root/kspy
diff options
context:
space:
mode:
Diffstat (limited to 'kspy')
-rw-r--r--kspy/classinfoview.cpp2
-rw-r--r--kspy/propsview.cpp46
-rw-r--r--kspy/receiversview.cpp10
-rw-r--r--kspy/receiversview.h2
-rw-r--r--kspy/sigslotview.cpp2
-rw-r--r--kspy/spy.cpp8
6 files changed, 35 insertions, 35 deletions
diff --git a/kspy/classinfoview.cpp b/kspy/classinfoview.cpp
index 0fa16c86..87f018bb 100644
--- a/kspy/classinfoview.cpp
+++ b/kspy/classinfoview.cpp
@@ -41,7 +41,7 @@ ClassInfoView::~ClassInfoView()
void ClassInfoView::buildList( TQObject *o )
{
- TQMetaObject *mo = o->tqmetaObject();
+ TQMetaObject *mo = o->metaObject();
for (int index = 0; index < mo->numClassInfo(true); index++) {
const TQClassInfo * classInfo = mo->classInfo(index, true);
diff --git a/kspy/receiversview.cpp b/kspy/receiversview.cpp
index 36e06e63..9cf31c31 100644
--- a/kspy/receiversview.cpp
+++ b/kspy/receiversview.cpp
@@ -1,5 +1,5 @@
/***************************************************************************
- tqreceiversview.cpp - description
+ receiversview.cpp - description
-------------------
begin : Tue Jan 11 2005
copyright : (C) 2005 by Richard Dale
@@ -20,7 +20,7 @@
#include <tqmetaobject.h>
#include <tqstrlist.h>
#include <tqvariant.h>
-#include <tqsignalslotimp.h>
+#include <signalslotimp.h>
#include <klocale.h>
@@ -28,7 +28,7 @@
class UnencapsulatedTQObject : public TQObject {
public:
- TQConnectionList *public_tqreceivers(int signal) const { return tqreceivers(signal); }
+ TQConnectionList *public_receivers(int signal) const { return receivers(signal); }
};
ReceiversView::ReceiversView(TQWidget *parent, const char *name ) : KListView(parent,name)
@@ -48,13 +48,13 @@ ReceiversView::~ReceiversView()
void ReceiversView::buildList( TQObject *o )
{
- TQMetaObject *mo = o->tqmetaObject();
+ TQMetaObject *mo = o->metaObject();
UnencapsulatedTQObject * qobject = (UnencapsulatedTQObject *) o;
TQStrList signalNames = mo->signalNames(true);
for (int sig = 0; sig < mo->numSignals(true); sig++) {
- TQConnectionList * clist = qobject->public_tqreceivers(sig);
+ TQConnectionList * clist = qobject->public_receivers(sig);
if (clist != 0) {
KListViewItem *conn = new KListViewItem( this, signalNames.at(sig) );
diff --git a/kspy/receiversview.h b/kspy/receiversview.h
index 6e703472..a0498b67 100644
--- a/kspy/receiversview.h
+++ b/kspy/receiversview.h
@@ -1,5 +1,5 @@
/***************************************************************************
- tqreceiversview.h - description
+ receiversview.h - description
-------------------
begin : Tue Jan 11 2005
copyright : (C) 2005 by Richard Dale
diff --git a/kspy/sigslotview.cpp b/kspy/sigslotview.cpp
index 97d024fb..d6fdba24 100644
--- a/kspy/sigslotview.cpp
+++ b/kspy/sigslotview.cpp
@@ -40,7 +40,7 @@ SigSlotView::~SigSlotView()
void SigSlotView::buildList( TQObject *o )
{
- TQMetaObject *mo = o->tqmetaObject();
+ TQMetaObject *mo = o->metaObject();
KListViewItem *sigs = new KListViewItem( this, "Signals" );
TQStrList sigList = mo->signalNames( true );
diff --git a/kspy/spy.cpp b/kspy/spy.cpp
index 1ef024d0..ec5d099d 100644
--- a/kspy/spy.cpp
+++ b/kspy/spy.cpp
@@ -19,7 +19,7 @@
#include <klocale.h>
#include <tqlabel.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqlistview.h>
#include <tqsplitter.h>
#include <ktabwidget.h>
@@ -47,10 +47,10 @@ extern "C"
Spy::Spy( TQWidget *parent, const char *name )
: TQWidget( parent, name )
{
- TQVBoxLayout *tqlayout = new TQVBoxLayout( this, 11, 6 );
+ TQVBoxLayout *layout = new TQVBoxLayout( this, 11, 6 );
TQSplitter *div = new TQSplitter( this );
- tqlayout->addWidget( div );
+ layout->addWidget( div );
TQVBox *leftPane = new TQVBox( div );
@@ -66,7 +66,7 @@ Spy::Spy( TQWidget *parent, const char *name )
mSigSlotView = new SigSlotView( tabs, "signals and slots view" );
tabs->addTab( mSigSlotView, i18n( "Signals && Slots" ) );
- mReceiversView = new ReceiversView( tabs, "tqreceivers view" );
+ mReceiversView = new ReceiversView( tabs, "receivers view" );
tabs->addTab( mReceiversView, i18n( "Receivers" ) );
mClassInfoView = new ClassInfoView( tabs, "class info view" );
diff --git a/kspy/propsview.cpp b/kspy/propsview.cpp
index 93747c28..8d099a94 100644
--- a/kspy/propsview.cpp
+++ b/kspy/propsview.cpp
@@ -35,15 +35,15 @@ public:
}
protected:
void paintCell( TQPainter * p, const TQColorGroup & cg,
- int column, int width, int tqalignment )
+ int column, int width, int alignment )
{
if (column == 1 && text(2) == "TQColor") {
TQColorGroup color_cg( cg.foreground(), cg.background(),
cg.light(), cg.dark(), cg.mid(),
TQColor(text(1)), TQColor(text(1)) );
- TQListViewItem::paintCell(p, color_cg, column, width, tqalignment);
+ TQListViewItem::paintCell(p, color_cg, column, width, alignment);
} else {
- KListViewItem::paintCell(p, cg, column, width, tqalignment);
+ KListViewItem::paintCell(p, cg, column, width, alignment);
}
}
};
@@ -69,7 +69,7 @@ PropsView::~PropsView()
void PropsView::buildList( TQObject *o )
{
- TQMetaObject *mo = o->tqmetaObject();
+ TQMetaObject *mo = o->metaObject();
TQStrList names = mo->propertyNames( true );
for ( uint i = 0; i < names.count(); i++ ) {
@@ -95,60 +95,60 @@ void PropsView::buildList( TQObject *o )
case TQVariant::Cursor:
{
TQCursor c = v.toCursor();
- val = TQString("tqshape=%1").tqarg(c.tqshape());
+ val = TQString("shape=%1").arg(c.shape());
break;
}
case TQVariant::Font:
{
TQFont f = v.toFont();
val = TQString("family=%1, pointSize=%2, weight=%3, italic=%4, bold=%5, underline=%6, strikeOut=%7")
- .tqarg(f.family())
- .tqarg(f.pointSize())
- .tqarg(f.weight())
- .tqarg(f.italic())
- .tqarg(f.bold())
- .tqarg(f.underline())
- .tqarg(f.strikeOut());
+ .arg(f.family())
+ .arg(f.pointSize())
+ .arg(f.weight())
+ .arg(f.italic())
+ .arg(f.bold())
+ .arg(f.underline())
+ .arg(f.strikeOut());
break;
}
case TQVariant::Int:
val.setNum( v.toInt() );
if (mp->isEnumType()) {
#ifdef USE_QT4
-// TQMetaObject * tqmetaObject = *(mp->meta); // FIXME
- val = TQString("%1::%2").tqarg("QT4_CANNOT_FIND_TQMETAOBJECT_FOR_TQMETAPROPERTY").tqarg(mp->valueToKey(val.toInt())); // FIXME
+// TQMetaObject * metaObject = *(mp->meta); // FIXME
+ val = TQString("%1::%2").arg("QT4_CANNOT_FIND_TQMETAOBJECT_FOR_TQMETAPROPERTY").arg(mp->valueToKey(val.toInt())); // FIXME
#else // USE_QT4
- TQMetaObject * tqmetaObject = *(mp->meta);
- val = TQString("%1::%2").tqarg(tqmetaObject->className()).tqarg(mp->valueToKey(val.toInt()));
+ TQMetaObject * metaObject = *(mp->meta);
+ val = TQString("%1::%2").arg(metaObject->className()).arg(mp->valueToKey(val.toInt()));
#endif // USE_QT4
}
break;
case TQVariant::Point:
{
TQPoint p = v.toPoint();
- val = TQString("x=%1, y=%2").tqarg(p.x()).tqarg(p.y());
+ val = TQString("x=%1, y=%2").arg(p.x()).arg(p.y());
break;
}
case TQVariant::Rect:
{
TQRect r = v.toRect();
val = TQString("left=%1, right=%2, top=%3, bottom=%4")
- .tqarg(r.left())
- .tqarg(r.right())
- .tqarg(r.top())
- .tqarg(r.bottom());
+ .arg(r.left())
+ .arg(r.right())
+ .arg(r.top())
+ .arg(r.bottom());
break;
}
case TQVariant::Size:
{
TQSize s = v.toSize();
- val = TQString("width=%1, height=%2").tqarg(s.width()).tqarg(s.height());
+ val = TQString("width=%1, height=%2").arg(s.width()).arg(s.height());
break;
}
case TQVariant::SizePolicy:
{
TQSizePolicy s = v.toSizePolicy();
- val = TQString("horData=%1, verData=%2").tqarg(s.horData()).tqarg(s.verData());
+ val = TQString("horData=%1, verData=%2").arg(s.horData()).arg(s.verData());
break;
}
case TQVariant::Double: